Enum cargo_issue_lib::Mode [−][src]
pub enum Mode {
Pipe,
Emit(Level),
Noop,
}Variants
Checks all tracked issues. More efficient than running the track macros during build time, as it can asynchronously obtain all information.
Emit(Level)Runs checks during build time. Level::Warn corresponds to build warnings, Level::Error
to build errors.
Performs no actions after parsing the attribute.